def external_tabular(descriptor):
    return 'url' in descriptor


def internal_tabular(descriptor):
    return 'path' in descriptor and \
           'schema' in descriptor and \
           'url' not in descriptor


def non_tabular(descriptor):
    return 'path' in descriptor and \
           'schema' not in descriptor and \
           'url' in descriptor



import os
import shutil

from datapackage_pipelines.lib.dump.dumper_base import FileDumper


class PathDumper(FileDumper):

    def initialize(self, params):
        super(PathDumper, self).initialize(params)
        self.out_path = params.get('out-path', '.')
        PathDumper.__makedirs(self.out_path)

    def write_file_to_output(self, filename, path):
        path = os.path.join(self.out_path, path)

        path_part = os.path.dirname(path)
        PathDumper.__makedirs(path_part)

        shutil.move(filename, path)

    @staticmethod
    def __makedirs(path):
        if not os.path.exists(path):
            os.makedirs(path)


PathDumper()()



from datapackage_pipelines.wrapper import ingest, spew
import os

parameters, datapackage, res_iter = ingest()


if datapackage is None:
    datapackage = {}

datapackage.setdefault('resources', [])

assert 'path' not in parameters, \
    "You can only add remote resources using this processor"

if parameters['url'].startswith('env://'):
    env_var = parameters['url'][6:]
    env_url = os.environ.get(env_var)
    assert env_url is not None, \
        "Couldn't connect to resource URL - " \
        "Please set your '%s' environment variable" % env_var

    parameters['url'] = env_url

for param in ['url', 'name']:
    assert param in parameters, \
        "You must define {} in your parameters".format(param)

datapackage['resources'].append(parameters)

spew(datapackage, res_iter)
